==> enterprisemodules-wls_config-3.4.0.tar.gz: enterprisemodules-wls_config-3.4.0/lib/puppet/type/wls_saf_error_handler.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_saf_error_handler) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage a SAF Error Handler in a JMS Module of a WebLogic domain.

    Here is an example on how you should use this:

        wls_saf_error_handler { 'jmsClusterModule:ErrorHandling-0':
          ensure => 'present',
          policy => 'Discard',
        }

    In this example you are managing a SAF error handler in the default domain. When you want to
    manage a SAF error handler in a specific domain, you can use:

        wls_saf_error_handler { 'my_domain/jmsClusterModule:ErrorHandling-1':
          ensure    => 'present',
          logformat => '%header%%properties%',
          policy    => 'Log',
        }

    EOD

    bean_path('/JMSSystemResources/%{jmsmodule}/JMSResource/%{jmsmodule}/SAFErrorHandlings')
    bean_type('SAFErrorHandling')

    ensurable
    parameter :error_handler_name
    parameter :domain
    parameter :name
    parameter :jmsmodule
    parameter :timeout
    # property :errordestination # TODO: Make this work
    property :logformat
    property :policy
    extraproperties do
      property :log_format
      property :notes
      property :saf_error_destination
      #
      # Weblogic 12.2.1 new properties
      #
    end

    add_title_attributes(:jmsmodule, :error_handler_name) do
      /(.+):(.+)/
    end
  end
end

==> enterprisemodules-wls_config-3.15.0.tar.gz: enterprisemodules-wls_config-3.15.0/lib/puppet/type/wls_saf_error_handler.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_saf_error_handler) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-DESC
    This resource allows you to manage a SAF Error Handler in a JMS Module of a WebLogic domain.

    Here is an example on how you should use this:

        wls_saf_error_handler { 'jmsClusterModule:ErrorHandling-0':
          ensure => 'present',
          policy => 'Discard',
        }

    In this example you are managing a SAF error handler in the default domain. When you want to
    manage a SAF error handler in a specific domain, you can use:

        wls_saf_error_handler { 'my_domain/jmsClusterModule:ErrorHandling-1':
          ensure    => 'present',
          logformat => '%header%%properties%',
          policy    => 'Log',
        }

    DESC

    bean_path('/JMSSystemResources/%<jmsmodule>s/JMSResource/%<jmsmodule>s/SAFErrorHandlings')
    bean_type('SAFErrorHandling')

    ensurable
    parameter :error_handler_name
    parameter :domain
    parameter :name
    parameter :jmsmodule
    parameter :timeout
    # property :errordestination # TODO: Make this work
    property :logformat
    property :policy
    extraproperties do
      property :log_format
      property :notes
      property :saf_error_destination
      #
      # Weblogic 12.2.1 new properties
      #
    end

    add_title_attributes(:jmsmodule, :error_handler_name) do
      /(.+):(.+)/
    end
  end
end
